@@ -1,10 +1,9 @@
 """Gets and caches things from Cloudformation"""
 import typing as ty
 
-from xoto3.lazy_session import tlls
+from xoto3.lazy_session import tll_from_session
 
-
-_CF_RESOURCE = tlls("resource", "cloudformation")
+_CF_RESOURCE = tll_from_session(lambda sess: sess.resource("cloudformation"))
 
 
 _STACKS: ty.Dict[str, ty.Any] = dict()
