@@ -4,7 +4,14 @@ Anything you import from any underlying module directly (i.e. not from
 here) is not guaranteed to remain, so don't do that. Import this
 module and use only what it exposes.
 """
-from .api2 import ItemTable, TypedTable, create_or_update, update_existing, update_if_exists  # noqa
+from .api2 import (  # noqa
+    ItemTable,
+    TypedTable,
+    create_or_update,
+    update_existing,
+    update_if_exists,
+    write_item,
+)
 from .errors import (  # noqa
     ItemUndefinedException,
     TableSchemaUnknownError,
