@@ -26,13 +26,23 @@ def sleep_join(
         yield
 
 
-def retry_while(strategy: ty.Iterable[ty.Callable[[Exception], bool]]) -> ty.Callable[[F], F]:
-    """Uses your retry strategy every time an exception is raised."""
+IsRetryable = ty.Callable[[Exception], bool]
+RetryStrategy = ty.Iterable[IsRetryable]
+RetryStrategyFactory = ty.Callable[[], RetryStrategy]
+
+
+def retry_while(strategy_factory: RetryStrategyFactory) -> ty.Callable[[F], F]:
+    """Uses your retry strategy every time an exception is raised.
+
+    Your iterable can therefore provide different handling for each
+    incrementing error, as well as configurable delays between errors,
+    etc.
+    """
 
     def _retry_decorator(func: F) -> F:
         @wraps(func)
         def retry_wrapper(*args, **kwargs):
-            for is_retryable in strategy:
+            for is_retryable in strategy_factory():
                 try:
                     return func(*args, **kwargs)
                 except Exception as e:
@@ -42,3 +52,9 @@ def retry_while(strategy: ty.Iterable[ty.Callable[[Exception], bool]]) -> ty.Cal
         return ty.cast(F, retry_wrapper)
 
     return _retry_decorator
+
+
+def sleep_between_expected_failures(
+    is_retryable: IsRetryable, seconds: ty.Iterable[float],
+) -> RetryStrategyFactory:
+    return lambda: (is_retryable for _ in sleep_join(seconds))
